/**
 * Android Application: LiveUOC
 * Treball fi de carrera
 * Universitat Oberta de Catalunya
 * 
 * @author Jose A. Serrano
 *
 */

package edu.uoc.Android.LiveUOC;

import java.io.IOException;
import java.net.MalformedURLException;
import java.net.URL;

import org.json.JSONException;
import org.json.JSONObject;

import edu.uoc.Android.LiveUOC.Objectes.UserLoged;
import android.app.Activity;
import android.content.ActivityNotFoundException;
import android.content.ComponentName;
import android.content.Intent;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.ImageButton;
import android.widget.ImageView;
import android.widget.TextView;
import android.widget.Toast;


public class MenuPrincipal extends Activity {

	// Atribut per a emmagtzemar les dades de l'usuari logejat
	protected UserLoged userLoged;
	protected String usuari;
	protected String foto;
	
	public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        
        // Mostrem el layout de pantalla
        setContentView(R.layout.menu);
        
        /*
         * Capturem els botons:
         * 		botoBustia		-> Llena l'aplicaci UOC Mail
         * 		botoAules		-> Llena l'activitat Aules
         * 		botoSecretaria	-> Llena l'activitat Secretaria
         * 		botoSortir		-> Torna enrera
         * 
         */
        final ImageButton botoBustia = (ImageButton) findViewById(R.id.botoBustia);
        final ImageButton botoAules = (ImageButton) findViewById(R.id.botoAules);
        final ImageButton botoSecretaria = (ImageButton) findViewById(R.id.botoSecretaria);
        final Button botoSortir = (Button) findViewById(R.id.botoSortir);
        
        // Pulsaci del Bot Bustia
        // Creem el seu onClickListener
        OnClickListener oclbotoBustia = new OnClickListener(){
			public void onClick(View v) {
				
				/*
				 *  Llenament de l'APP UOCMail
				 *  
				 *  	Package:		edu.uoc.webmail.android
				 *  	MainActivity:	edu.uoc.webmail.android.Start
				 *  
				 */
				String packUocMail = "edu.uoc.webmail.android";
				String MainActivity = "edu.uoc.webmail.android.Start";
				
				// Comprobem si l'APP est installada:
				Intent intent = new Intent(Intent.ACTION_MAIN);
				intent.setComponent(new ComponentName(packUocMail,MainActivity));
				try {
					startActivity(intent);
				} catch (ActivityNotFoundException e) {
					// NO Existeix UOCMail al sistema
					// Informem a l'usuari que se'l desarregui del market:
					Toast.makeText(MenuPrincipal.this, 
							"La APP UOCMail no s'ha trobat al sistema.\n" +
							"La pots descarregar del Market." , 5).show();
				}
			}
		};        
        // Registrem el seu callback
		botoBustia.setOnClickListener(oclbotoBustia);
        
		// Pulsaci del Bot Aules
        // Creem el seu onClickListener
        OnClickListener oclbotoAules = new OnClickListener(){
			public void onClick(View v) {
				
				// Creem el intent per a llenar l'aplicaci
				Intent intent = new Intent();
				intent.setClass(getApplicationContext(), AulesActivity.class);
				startActivity(intent);
				
			}
		};        
        // Registrem el seu callback
		botoAules.setOnClickListener(oclbotoAules);
		
		// Pulsaci del Bot Secretaria
        // Creem el seu onClickListener
        OnClickListener oclbotoSecretaria = new OnClickListener(){
			public void onClick(View v) {
				
				// Creem el intent per a llenar l'aplicaci
				Intent intent = new Intent();
				intent.setClass(getApplicationContext(), SecretariaActivity.class);
				startActivity(intent);
				
			}
		};        
        // Registrem el seu callback
		botoSecretaria.setOnClickListener(oclbotoSecretaria);
		
        // Pulsaci del Bot Sortir
        // Creem el seu onClickListener
        OnClickListener oclbotoSortir = new OnClickListener(){
			public void onClick(View v) {
				finish();
			}
		};        
        // Registrem el seu callback
		botoSortir.setOnClickListener(oclbotoSortir);
	}
	
	public void onStart(){
		super.onStart();
		
		// Recuperem l'objecte JSON amb les dades de l'usuari autenticat:
		Bundle bundle = getIntent().getExtras();
		
		// Creem l'objecte JSON:
		JSONObject userJSON = null;
		try {
			userJSON = new JSONObject(bundle.getString("JSON"));
		} catch (JSONException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		
		// Actualitzem els atributs
		userLoged = new UserLoged(userJSON, true);
		usuari = userLoged.getCustom_fullname();
		foto = userLoged.getCustom_photo();
		
		// DEBUG:
		Log.d("MENU PRINCIPAL - ", "userJSON: " + userJSON.toString());
		Log.d("MENU PRINCIPAL - ", "Usuari: " + userLoged.getCustom_username());
		Log.d("MENU PRINCIPAL - ", "Nom complet: " + usuari);
		Log.d("MENU PRINCIPAL - ", "URL foto: " + foto);
		
		/*
		 *  Capturem els camps per a mostrar les dades de l'usuari autenticat:
		 *  
		 *  Foto de l'usuari: (96x132)
		 *  	id = fotoUsuari
		 *  
		 *  Sistema de crrega:
		 *  	imgView.setImageURI(Uri.parse("URL"));
		 *  
		 *  Usuari:
		 *  	id = nomUsuari
		 */
		final ImageView fotoUsuari = (ImageView) findViewById(R.id.fotoUsuari);
		final TextView nomUsuari = (TextView) findViewById(R.id.nomUsuari);
		
		// Fiquem la foto:
		URL url = null;
		try {
			url = new URL(foto);
		} catch (MalformedURLException e1) {
			// TODO Auto-generated catch block
			e1.printStackTrace();
		}
		Bitmap bmp = null;
		try {
			bmp = BitmapFactory.decodeStream(url.openConnection().getInputStream());
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		fotoUsuari.setImageBitmap(bmp);
		// fotoUsuari.setImageURI(Uri.parse(foto));
		
		// Fiquem el nom d'usuari:
		nomUsuari.setText(usuari);

		
	}
}
